@@ -1,7 +1,7 @@
 //
 // This file is part of go-algorithms.
 //
-// Copyright 2024 Cristian Maglie. All rights reserved.
+// Copyright 2024 go-algorithms (go.bug.st/f) authors. All rights reserved.
 // Use of this source code is governed by a BSD-style
 // license that can be found in the LICENSE file.
 //
@@ -19,6 +19,13 @@ func Must[T any](val T, err error) T {
 	return val
 }
 
+// NoError panics if the given error is not nil.
+func NoError(err error) {
+	if err != nil {
+		panic(err.Error())
+  }
+}
+
 // Assert panics if condition is false.
 func Assert(condition bool, msg string, args ...any) {
 	if !condition {
